@@ -4,7 +4,12 @@ from .. import Provider as ColorProvider
 
 
 class Provider(ColorProvider):
-    # Source: uk.wikipedia.org/wiki/Список_кольорів
+    """Implement color provider for ``uk_UA`` locale.
+
+    Sources:
+    - https://uk.wikipedia.org/wiki/Список_кольорів
+    """
+
     all_colors = OrderedDict((
         ('Абрикосовий', '#FBCEB1'),
         ('Аквамариновий', '#7FFFD4'),
